Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(704)

Unified Diff: chrome/browser/resources/bluetooth_internals/expandable_list.js

Issue 2640073004: bluetooth: Add descriptor list to DeviceDetailsPage on internals page. (Closed)
Patch Set: Fix merge issue of bluetooth_internals.css Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/resources/bluetooth_internals/expandable_list.js
diff --git a/chrome/browser/resources/bluetooth_internals/expandable_list.js b/chrome/browser/resources/bluetooth_internals/expandable_list.js
index 81de23fe1791a95e7c7ca6b4bcde4d7788641bd3..5f543e688e1fc65b11d27c714bb46948565efb4f 100644
--- a/chrome/browser/resources/bluetooth_internals/expandable_list.js
+++ b/chrome/browser/resources/bluetooth_internals/expandable_list.js
@@ -84,7 +84,7 @@ cr.define('expandable_list', function() {
this.autoExpands = true;
this.boundUpdateMessage_ = this.updateMessageDisplay_.bind(this);
- this.setLoading(true);
+ this.setSpinnerShowing(true);
},
/**
@@ -109,19 +109,19 @@ cr.define('expandable_list', function() {
},
/**
* Sets the loading state of the list. If |loading| is true, the loading
* spinner is dispayed.
- * @param {boolean} loading
+ * @param {boolean} showing
*/
- setLoading: function(loading) {
- this.spinner_.hidden = !loading;
+ setSpinnerShowing: function(showing) {
+ this.spinner_.hidden = !showing;
},
/**
- * Gets the loading state of the list. Returns true if the list is loading.
+ * Gets the spinner display state. Returns true if the spinner is showing.
* @return {boolean}
*/
- isLoading: function() {
+ isSpinnerShowing: function() {
return !this.spinner_.hidden;
},
@@ -109,19 +109,19 @@ cr.define('expandable_list', function() {
},
/**
- * Sets the loading state of the list. If |loading| is true, the loading
+ * Sets the spinner display state. If |showing| is true, the loading
* spinner is dispayed.

Powered by Google App Engine
This is Rietveld 408576698